module.exports={A:{A:{"2436":"L D E F A B 7C"},B:{"260":"P Q","2436":"C M N G O","8196":"0 1 2 3 4 5 6 7 8 9 R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I"},C:{"2":"8C aC J hB L D E F A B C M N G O P Q iB DB EB BD CD","772":"FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB","4100":"0 1 2 3 4 5 6 7 8 9 tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD"},D:{"2":"J hB L D E F A B C","2564":"M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB","8196":"0 1 2 3 4 5 6 7 8 9 AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","10244":"vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B"},E:{"1":"C M N G K VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD","16":"DD gC","2308":"A B hC UC","2820":"J hB L D E F ED FD GD HD"},F:{"2":"F B PD QD RD SD UC 5C TD","16":"C","516":"VC","2564":"G O P Q iB DB EB FB GB HB IB JB K KB LB","8196":"0 1 2 3 4 5 6 7 8 9 xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB","10244":"MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB"},G:{"1":"fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C","2":"gC UD 6C","2820":"E VD WD XD YD ZD aD bD cD dD eD"},H:{"2":"rD"},I:{"2":"aC J sD tD uD vD 6C","260":"I","2308":"wD xD"},J:{"2":"D","2308":"A"},K:{"2":"A B C UC 5C","16":"VC","8196":"H"},L:{"8196":"I"},M:{"1028":"TC"},N:{"2":"A B"},O:{"8196":"WC"},P:{"2052":"yD zD","2308":"J","8196":"DB EB FB GB HB IB JB K KB LB MB 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"8196":"9D"},R:{"8196":"AE"},S:{"4100":"BE CE"}},B:5,C:"Synchronous Clipboard API",D:true};
