function readInputSourceMapFile() {
  throw new Error("Reading input source map files is not supported in browsers");
}

export { readInputSourceMapFile as default };
//# sourceMappingURL=read-input-source-map-file-browser.js.map
