module.exports={A:{A:{"1":"B","2":"L D E F A 7C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 N G O P Q R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I","129":"C M"},C:{"1":"0 1 2 3 4 5 6 7 8 9 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD","2":"8C aC","260":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B","804":"J hB L D E F A B C M N BD CD"},D:{"1":"0 1 2 3 4 5 6 7 8 9 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","260":"3B 4B 5B 6B 7B","388":"MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B","1412":"G O P Q iB DB EB FB GB HB IB JB K KB LB","1956":"J hB L D E F A B C M N"},E:{"1":"K jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD","129":"A B C M N G HD hC UC VC ID JD KD iC","1412":"L D E F FD GD","1956":"J hB DD gC ED"},F:{"1":"0 1 2 3 4 5 6 7 8 9 vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB","2":"F PD QD","260":"qB rB sB tB uB","388":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB","1796":"RD SD","1828":"B C UC 5C TD VC"},G:{"1":"jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C","129":"aD bD cD dD eD fD gD hD iD jD kD lD mD nD iC","1412":"E WD XD YD ZD","1956":"gC UD 6C VD"},H:{"1828":"rD"},I:{"1":"I","388":"wD xD","1956":"aC J sD tD uD vD 6C"},J:{"1412":"A","1924":"D"},K:{"1":"H","2":"A","1828":"B C UC 5C VC"},L:{"1":"I"},M:{"1":"TC"},N:{"1":"B","2":"A"},O:{"1":"WC"},P:{"1":"DB EB FB GB HB IB JB K KB LB MB 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D","260":"yD zD","388":"J"},Q:{"1":"9D"},R:{"1":"AE"},S:{"1":"CE","260":"BE"}},B:4,C:"CSS3 Border images",D:true};
