module.exports={A:{A:{"1":"B","4":"L D E F A 7C"},B:{"1":"C M N G O","129":"0 1 2 3 4 5 6 7 8 9 P Q R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I"},C:{"1":"L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B","4":"8C aC J hB BD CD","129":"0 1 2 3 4 5 6 7 8 9 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD"},D:{"1":"xB yB zB 0B 1B 2B 3B 4B 5B 6B","4":"J hB L","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC"},E:{"4":"J hB DD gC","129":"L D E F A B C M N G K ED FD GD HD hC UC VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD"},F:{"1":"C kB lB mB nB oB pB qB rB sB tB UC 5C TD VC","4":"F B PD QD RD SD","129":"0 1 2 3 4 5 6 7 8 9 G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB"},G:{"4":"gC UD 6C","129":"E VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C"},H:{"4":"rD"},I:{"4":"sD tD uD","129":"aC J I vD 6C wD xD"},J:{"129":"D A"},K:{"1":"C UC 5C VC","4":"A B","129":"H"},L:{"129":"I"},M:{"129":"TC"},N:{"1":"B","4":"A"},O:{"129":"WC"},P:{"129":"J DB EB FB GB HB IB JB K KB LB MB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"129":"9D"},R:{"129":"AE"},S:{"1":"BE","129":"CE"}},B:1,C:"dataset & data-* attributes",D:true};
