module.exports={A:{A:{"2":"L D E F A B 7C"},B:{"2":"C M N G O P Q","1025":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I","1537":"R H S T U V W X Y Z a b c d"},C:{"2":"8C","932":"aC J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC BD CD","2308":"0 1 2 3 4 5 6 7 8 9 GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD"},D:{"2":"J hB L D E F A B C M N G O P Q iB DB EB","545":"FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB","1025":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","1537":"yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d"},E:{"1":"K XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD","2":"J hB L DD gC ED","516":"B C M N G UC VC ID JD KD iC jC WC LD","548":"F A HD hC","676":"D E FD GD"},F:{"2":"F B C PD QD RD SD UC 5C TD VC","513":"mB","545":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB","1025":"0 1 2 3 4 5 6 7 8 9 f g h i j k l m n o p q r s t u v w x y z AB BB CB","1537":"lB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e"},G:{"1":"XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C","2":"gC UD 6C VD WD","516":"lD mD nD iC jC WC oD","548":"ZD aD bD cD dD eD fD gD hD iD jD kD","676":"E XD YD"},H:{"2":"rD"},I:{"2":"aC J sD tD uD vD 6C","545":"wD xD","1025":"I"},J:{"2":"D","545":"A"},K:{"2":"A B C UC 5C VC","1025":"H"},L:{"1025":"I"},M:{"2308":"TC"},N:{"2":"A B"},O:{"1537":"WC"},P:{"545":"J","1025":"DB EB FB GB HB IB JB K KB LB MB YC ZC 8D","1537":"yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC"},Q:{"1537":"9D"},R:{"1537":"AE"},S:{"932":"BE","2308":"CE"}},B:5,C:"Intrinsic & Extrinsic Sizing",D:true};
