module.exports={A:{A:{"2":"L D E F 7C","8":"A B"},B:{"1":"R","2":"0 1 2 3 4 5 6 7 8 9 H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I","8":"C M N G O P Q"},C:{"2":"0 1 2 3 4 5 6 7 8 9 8C aC J hB L D E F A B C M N G O P Q iB DB EB FB bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD BD CD","66":"GB HB IB JB K KB LB","72":"MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC"},D:{"1":"lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R","2":"0 1 2 3 4 5 6 7 8 9 J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","66":"K KB LB MB jB kB"},E:{"2":"J hB DD gC ED","8":"L D E F A B C M N G K FD GD HD hC UC VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD"},F:{"1":"DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC","2":"0 1 2 3 4 5 6 7 8 9 F B C HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB PD QD RD SD UC 5C TD VC","66":"G O P Q iB"},G:{"2":"gC UD 6C VD WD","8":"E XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C"},H:{"2":"rD"},I:{"1":"xD","2":"aC J I sD tD uD vD 6C wD"},J:{"2":"D A"},K:{"2":"A B C H UC 5C VC"},L:{"2":"I"},M:{"2":"TC"},N:{"2":"A B"},O:{"1":"WC"},P:{"1":"J yD zD 0D 1D 2D hC 3D 4D","2":"DB EB FB GB HB IB JB K KB LB MB 5D 6D 7D XC YC ZC 8D"},Q:{"1":"9D"},R:{"2":"AE"},S:{"2":"CE","72":"BE"}},B:7,C:"Custom Elements (deprecated V0 spec)",D:true};
