module.exports={A:{A:{"2":"L D E 7C","2561":"A B","2692":"F"},B:{"1":"0 1 2 3 4 5 6 7 8 9 R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I","2561":"C M N G O P Q"},C:{"1":"0 1 2 3 4 5 6 7 8 9 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD","16":"8C","1537":"J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B CD","1796":"aC BD"},D:{"1":"0 1 2 3 4 5 6 7 8 9 GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","16":"J hB L D E F A B C M N","1025":"nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC","1537":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB"},E:{"1":"N G K ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD","16":"J hB L DD gC","1025":"D E F A B C FD GD HD hC UC","1537":"ED","4097":"M VC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB VC","16":"F B C PD QD RD SD UC 5C","260":"TD","1025":"FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B","1537":"G O P Q iB DB EB"},G:{"1":"iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C","16":"gC UD 6C","1025":"E YD ZD aD bD cD dD eD fD","1537":"VD WD XD","4097":"gD hD"},H:{"2":"rD"},I:{"16":"sD tD","1025":"I xD","1537":"aC J uD vD 6C wD"},J:{"1025":"A","1537":"D"},K:{"1":"A B C H UC 5C VC"},L:{"1":"I"},M:{"1":"TC"},N:{"2561":"A B"},O:{"1":"WC"},P:{"1025":"J DB EB FB GB HB IB JB K KB LB MB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"1":"9D"},R:{"1":"AE"},S:{"1":"CE","1537":"BE"}},B:1,C:"input event",D:true};
