module.exports={A:{A:{"2":"L D E F 7C","132":"A B"},B:{"132":"C M N G O P Q","1028":"0 1 2 3 4 5 6 7 8 9 R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I"},C:{"2":"8C aC J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB BD CD","1028":"0 1 2 3 4 5 6 7 8 9 JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD","2564":"lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B","3076":"1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC"},D:{"16":"J hB L D","132":"F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC","388":"E","1028":"0 1 2 3 4 5 6 7 8 9 cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC"},E:{"16":"J DD gC","132":"hB L D E F A ED FD GD HD hC","1028":"B C M N G K UC VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD"},F:{"2":"F B C PD QD RD SD UC 5C TD VC","132":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB","1028":"0 1 2 3 4 5 6 7 8 9 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB"},G:{"16":"gC UD 6C","132":"E VD WD XD YD ZD aD bD cD","1028":"dD eD fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C"},H:{"2":"rD"},I:{"132":"J vD 6C wD xD","292":"aC sD tD uD","1028":"I"},J:{"16":"D","132":"A"},K:{"2":"A B C UC 5C VC","1028":"H"},L:{"1028":"I"},M:{"1028":"TC"},N:{"132":"A B"},O:{"1028":"WC"},P:{"132":"J DB EB FB GB HB IB JB K KB LB MB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"1028":"9D"},R:{"1028":"AE"},S:{"1028":"CE","2564":"BE"}},B:4,C:"DOMMatrix",D:true};
