module.exports={A:{A:{"1":"A B","2":"L D E F 7C"},B:{"1":"C M N G O P Q","516":"0 1 2 3 4 5 6 7 8 9 R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I"},C:{"132":"4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC","164":"8C aC J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B BD CD","516":"FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b","1028":"0 1 2 3 4 5 6 7 8 9 c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD"},D:{"420":"J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B","516":"0 1 2 3 4 5 6 7 8 9 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC"},E:{"1":"A B C M N G K hC UC VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD","132":"F HD","164":"D E GD","420":"J hB L DD gC ED FD"},F:{"1":"C UC 5C TD VC","2":"F B PD QD RD SD","420":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB","516":"0 1 2 3 4 5 6 7 8 9 pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB"},G:{"1":"bD cD dD eD fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C","132":"ZD aD","164":"E XD YD","420":"gC UD 6C VD WD"},H:{"1":"rD"},I:{"420":"aC J sD tD uD vD 6C wD xD","516":"I"},J:{"420":"D A"},K:{"1":"C UC 5C VC","2":"A B","516":"H"},L:{"516":"I"},M:{"1028":"TC"},N:{"1":"A B"},O:{"516":"WC"},P:{"420":"J","516":"DB EB FB GB HB IB JB K KB LB MB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"516":"9D"},R:{"516":"AE"},S:{"164":"BE CE"}},B:4,C:"CSS3 Multiple column layout",D:true};
