module.exports={A:{A:{"2":"F A B 7C","8":"L D E"},B:{"2":"C M N G O P Q","8":"R H S T U V W X Y Z a b c d e f g","584":"h i j k l m n o p q r s","1025":"0 1 2 3 4 5 6 7 8 9 t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD","129":"8C aC BD CD"},D:{"1":"HB","8":"J hB L D E F A B C M N G O P Q iB DB EB FB GB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g","584":"h i j k l m n o p q r s","1025":"0 1 2 3 4 5 6 7 8 9 t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC"},E:{"1":"A B C M N G K hC UC VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD","260":"J hB L D E F DD gC ED FD GD HD"},F:{"2":"F","8":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC","584":"T U V W X Y Z a b c d e","1025":"0 1 2 3 4 5 6 7 8 9 f g h i j k l m n o p q r s t u v w x y z AB BB CB","2052":"B C PD QD RD SD UC 5C TD VC"},G:{"1":"E VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C","8":"gC UD 6C"},H:{"8":"rD"},I:{"8":"aC J sD tD uD vD 6C wD xD","1025":"I"},J:{"1":"A","8":"D"},K:{"8":"A B C UC 5C VC","1025":"H"},L:{"1025":"I"},M:{"1":"TC"},N:{"2":"A B"},O:{"8":"WC"},P:{"1":"EB FB GB HB IB JB K KB LB MB","8":"J DB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"8":"9D"},R:{"8":"AE"},S:{"1":"BE CE"}},B:2,C:"MathML",D:true};
