import { _codeFrameColumns } from './common-shared.js';

function codeFrameColumns(rawLines, loc, opts = {}) {
  return _codeFrameColumns(rawLines, loc, opts);
}
function highlight(code) {
  return code;
}

export { codeFrameColumns, highlight };
//# sourceMappingURL=browser.js.map
