module.exports={A:{A:{"2":"L D E 7C","260":"F A B"},B:{"2":"VB WB XB YB ZB aB bB cB dB eB fB gB I","66":"BB NB OB PB CB QB RB SB TB UB","132":"0 1 2 3 4 5 6 7 8 9 R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB","260":"C M N G O P Q"},C:{"2":"8C aC J hB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD BD CD","260":"0 1 2 3 4 5 6 7 8 9 L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB"},D:{"2":"TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","16":"J hB L D E F A B C M N","66":"BB NB OB PB CB QB RB SB","132":"0 1 2 3 4 5 6 7 8 9 G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB"},E:{"2":"K zC 0C 1C 2C 3C 4C OD","16":"DD gC","132":"J hB L D E F A B C M N G ED FD GD HD hC UC VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC"},F:{"1":"C TD VC","2":"F PD QD RD SD","16":"B UC 5C","66":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB","132":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w"},G:{"2":"zC 0C 1C 2C 3C 4C","16":"gC UD","132":"E 6C VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC"},H:{"2":"rD"},I:{"2":"I","16":"sD tD","132":"aC J uD vD 6C wD xD"},J:{"132":"D A"},K:{"1":"C VC","2":"A","16":"B UC 5C","132":"H"},L:{"2":"I"},M:{"2":"TC"},N:{"260":"A B"},O:{"132":"WC"},P:{"132":"J DB EB FB GB HB IB JB K KB LB MB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"132":"9D"},R:{"132":"AE"},S:{"260":"BE CE"}},B:7,C:"Mutation events",D:true};
