export { DEFAULT_EXTENSIONS, File, buildExternalHelpers, createConfigItem, createConfigItemAsync, createConfigItemSync, getEnv, loadOptions, loadOptionsAsync, loadOptionsSync, loadPartialConfig, loadPartialConfigAsync, loadPartialConfigSync, parse, parseAsync, parseSync, resolvePlugin, resolvePreset, transform, transformAsync, transformFromAst, transformFromAstAsync, transformFromAstSync, transformSync, version } from './index-shared.js';
import '#config/files';
import * as _t from '@babel/types';
export { _t as types };
export { tokTypes } from '@babel/parser';
export { default as traverse } from '@babel/traverse';
export { default as template } from '@babel/template';
export { transformFile, transformFileAsync, transformFileSync } from '#transform-file';
//# sourceMappingURL=index.js.map
