type Location = {
    column: number;
    line: number;
};
type NodeLocation = {
    end?: Location;
    start: Location;
};
interface Options {
    /** Syntax highlight the code as JavaScript for terminals. default: false */
    highlightCode?: boolean;
    /**  The number of lines to show above the error. default: 2 */
    linesAbove?: number;
    /**  The number of lines to show below the error. default: 3 */
    linesBelow?: number;
    startLine?: number;
    /**
     * Forcibly syntax highlight the code as JavaScript (for non-terminals);
     * overrides highlightCode.
     * default: false
     */
    forceColor?: boolean;
    /**
     * Pass in a string to be displayed inline (if possible) next to the
     * highlighted location in the code. If it can't be positioned inline,
     * it will be placed above the code frame.
     * default: nothing
     */
    message?: string;
}

declare function highlight(text: string): string;

declare function codeFrameColumns(rawLines: string, loc: NodeLocation, opts?: Options): string;

export { type Options, codeFrameColumns, highlight };
