module.exports={A:{D:{"1":"UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","2":"J hB L D E F A B C M N G O","33":"0 1 2 3 4 5 6 7 8 9 P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB"},L:{"1":"I"},B:{"1":"UB VB WB XB YB ZB aB bB cB dB eB fB gB I","2":"C M N G O P Q","33":"0 1 2 3 4 5 6 7 8 9 R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB"},C:{"1":"0 1 2 3 4 5 6 7 8 9 h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD","2":"8C aC J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB BD CD","33":"0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g"},M:{"1":"TC"},A:{"2":"L D E F A B 7C"},F:{"1":"5 6 7 8 9 AB BB CB","2":"F B C PD QD RD SD UC 5C TD VC","33":"0 1 2 3 4 G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},K:{"2":"A B C UC 5C VC","33":"H"},E:{"1":"K jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C","2":"J hB DD gC ED OD","33":"L D E F A B C M N G FD GD HD hC UC VC ID JD KD iC"},G:{"1":"jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C","2":"gC UD 6C VD","33":"E WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD nD iC"},P:{"1":"LB MB","33":"J DB EB FB GB HB IB JB K KB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},I:{"1":"I","2":"aC J sD tD uD vD 6C","33":"wD xD"}},B:6,C:"print-color-adjust property",D:undefined};
