module.exports={A:{A:{"388":"A B","900":"L D E F 7C"},B:{"388":"C M N G O P Q","641":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I","900":"R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r"},C:{"772":"0 1 2 3 4 5 6 7 8 9 FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD","900":"8C aC J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC BD CD"},D:{"641":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","900":"J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r"},E:{"772":"A","900":"J hB L D E F B C M N G K DD gC ED FD GD HD hC UC VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD"},F:{"16":"F PD","129":"B C QD RD SD UC 5C TD VC","641":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w x y z AB BB CB","900":"G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d"},G:{"900":"E gC UD 6C VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C"},H:{"129":"rD"},I:{"641":"I","900":"aC J sD tD uD vD 6C wD xD"},J:{"900":"D A"},K:{"129":"A B C UC 5C VC","641":"H"},L:{"900":"I"},M:{"772":"TC"},N:{"388":"A B"},O:{"900":"WC"},P:{"641":"EB FB GB HB IB JB K KB LB MB","900":"J DB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"900":"9D"},R:{"900":"AE"},S:{"772":"CE","900":"BE"}},B:2,C:"CSS page-break properties",D:true};
