module.exports={A:{A:{"2":"L D E F 7C","129":"A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I","129":"C M","1025":"N G O P Q"},C:{"2":"8C aC J hB L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB BD CD","513":"0 1 2 3 4 5 6 7 8 9 LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC 9C AD"},D:{"1":"0 1 2 3 4 5 6 7 8 9 L D E F A B C M N G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC bC BC cC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB NB OB PB CB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB fB gB I eC TC fC","2":"J hB"},E:{"1":"hB L D E F A B C M N G K ED FD GD HD hC UC VC ID JD KD iC jC WC LD XC kC lC mC nC oC MD YC pC qC rC sC tC ND ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C OD","2":"J DD gC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 F B C G O P Q iB DB EB FB GB HB IB JB K KB LB MB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC SC R H S dC T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB PD QD RD SD UC 5C TD VC"},G:{"388":"E gC UD 6C VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD nD iC jC WC oD XC kC lC mC nC oC pD YC pC qC rC sC tC qD ZC uC vC wC xC yC zC 0C 1C 2C 3C 4C"},H:{"2":"rD"},I:{"2":"aC sD tD uD","388":"J I vD 6C wD xD"},J:{"2":"D","388":"A"},K:{"1":"A B C UC 5C VC","388":"H"},L:{"388":"I"},M:{"641":"TC"},N:{"388":"A B"},O:{"388":"WC"},P:{"388":"J DB EB FB GB HB IB JB K KB LB MB yD zD 0D 1D 2D hC 3D 4D 5D 6D 7D XC YC ZC 8D"},Q:{"388":"9D"},R:{"388":"AE"},S:{"513":"BE CE"}},B:1,C:"Number input type",D:true};
